dragsheet library

Classes

BgOpacity
Configuration for the background scrim of the DragSheet.
DragSheet
A widget that can be dragged and dismissed, typically used for modal sheets.
DragSheetController
Manages the presentation and dismissal of a DragSheet.

Enums

ApplyBorderRadius
Defines which corners of the sheet should have a border radius.

Properties

borderRadius BorderRadius
Defines the default border radius for certain sheet elements.
final